@@ -6,13 +6,13 @@ WWW::Mechanize - Handy web browsing in a Perl object
 
 =head1 VERSION
 
-Version 0.62
+Version 0.63
 
-    $Header: /cvsroot/www-mechanize/www-mechanize/lib/WWW/Mechanize.pm,v 1.71 2003/10/08 01:50:53 petdance Exp $
+    $Header: /cvsroot/www-mechanize/www-mechanize/lib/WWW/Mechanize.pm,v 1.75 2003/10/13 16:47:14 petdance Exp $
 
 =cut
 
-our $VERSION = "0.62";
+our $VERSION = "0.63";
 
 =head1 SYNOPSIS
 
@@ -33,17 +33,17 @@ a history of the URLs you've visited, which can be queried and revisited.
     $a->follow_link( url => 'http://host.com/index.html' );
 
     $a->submit_form(
-	form_number => 3,
-	fields      => {
-			username    => 'yourname',
-			password    => 'dummy',
-			}
+        form_number => 3,
+        fields      => {
+                        username    => 'yourname',
+                        password    => 'dummy',
+                        }
     );
 
     $a->submit_form(
-	form_name => 'search',
-	fields    => { query  => 'pot of gold', },
-	button    => 'Search Now'
+        form_name => 'search',
+        fields    => { query  => 'pot of gold', },
+        button    => 'Search Now'
     );
 
 
@@ -102,20 +102,35 @@ See L<http://www.oreilly.com/catalog/spiderhks/> for more info.
 
 =over 4
 
+=item * WWW::Mechanize Development mailing list
+
+Hosted at Sourceforge, this is where the contributors to Mech
+discuss things.  L<http://sourceforge.net/mail/?group_id=83309>
+
+=item * LWP mailing list
+
+The LWP mailing list is at
+L<http://lists.perl.org/showlist.cgi?name=libwww>, and is more
+user-oriented and well-populated than the WWW::Mechanize Development
+list.  This is a good list for Mech users, since LWP is the basis
+for Mech.
+
 =item * L<WWW::Mechanize::Examples>
 
-A random array of examples submitted by users.
+A random array of examples submitted by users, included with the
+Mechanize distribution.
 
 =item * L<http://www.perl.com/pub/a/2003/01/22/mechanize.html>
 
-Chris Ball's article about using WWW::Mechanize for scraping TV listings.
+Chris Ball's article about using WWW::Mechanize for scraping TV
+listings.
 
 =item * L<http://www.stonehenge.com/merlyn/LinuxMag/col47.html>
 
-Randal Schwartz's article on scraping Yahoo News for images.  It's already
-out of date: He manually walks the list of links hunting for matches,
-which wouldn't have been necessary if the C<find_link()> method existed
-at press time.
+Randal Schwartz's article on scraping Yahoo News for images.  It's
+already out of date: He manually walks the list of links hunting
+for matches, which wouldn't have been necessary if the C<find_link()>
+method existed at press time.
 
 =item * L<http://www.perladvent.org/2002/16th/>
 
@@ -168,13 +183,13 @@ parms that L<LWP::UserAgent> recognizes.
 
 =over 4
 
-=item * autocheck => [0|1]
+=item * C<< autocheck => [0|1] >>
 
 Checks each request made to see if it was successful.  This saves you
 the trouble of manually checking yourself.  Any errors found are errors,
 not warnings.  Default is off.
 
-=item * onwarn => \&func()
+=item * C<< onwarn => \&func() >>
 
 Reference to a C<warn>-compatible function, such as C<< L<Carp>::carp >>,
 that is called when a warning needs to be shown.
@@ -185,7 +200,7 @@ it's probably better to use the C<quiet> method to control that behavior.
 If this value is not passed, Mech uses C<Carp::carp> if L<Carp> is
 installed, or C<CORE::warn> if not.
 
-=item * onerror => \&func()
+=item * C<< onerror => \&func() >>
 
 Reference to a C<die>-compatible function, such as C<< L<Carp>::croak >>,
 that is called when there's a fatal error.
@@ -195,7 +210,7 @@ If this is set to C<undef>, no errors will ever be shown.
 If this value is not passed, Mech uses C<Carp::croak> if L<Carp> is
 installed, or C<CORE::die> if not.
 
-=item * quiet => [0|1]
+=item * C<< quiet => [0|1] >>
 
 Don't complain on warnings.  Setting C<< quiet => 1 >> is the same as
 calling C<< $agent->quiet(1) >>.  Default is off.
@@ -208,26 +223,26 @@ sub new {
     my $class = shift;
 
     my %parent_parms = (
-        agent	    => "WWW-Mechanize/$VERSION",
+        agent       => "WWW-Mechanize/$VERSION",
         cookie_jar  => {},
     );
 
     my %mech_parms = (
-	autocheck   => 0,
-	onwarn	    => \&WWW::Mechanize::_warn,
-	onerror	    => \&WWW::Mechanize::_die,
-	quiet	    => 0,
+        autocheck   => 0,
+        onwarn      => \&WWW::Mechanize::_warn,
+        onerror     => \&WWW::Mechanize::_die,
+        quiet       => 0,
     );
 
     my %passed_parms = @_;
 
     # Keep the mech-specific parms before creating the object.
     while ( my($key,$value) = each %passed_parms ) {
-	if ( exists $mech_parms{$key} ) {
-	    $mech_parms{$key} = $value;
-	} else {
-	    $parent_parms{$key} = $value;
-	}
+        if ( exists $mech_parms{$key} ) {
+            $mech_parms{$key} = $value;
+        } else {
+            $parent_parms{$key} = $value;
+        }
     }
 
     my $self = $class->SUPER::new( %parent_parms );
@@ -235,7 +250,7 @@ sub new {
 
     # Use the mech parms now that we have a mech object.
     for my $parm ( keys %mech_parms ) {
-	$self->{$parm} = $mech_parms{$parm};
+        $self->{$parm} = $mech_parms{$parm};
     }
     $self->{page_stack} = [];
     $self->env_proxy();
@@ -280,12 +295,12 @@ The list of valid aliases can be returned from C<known_agent_aliases()>.
 =cut
 
 my %known_agents = (
-    'Windows IE 6'	=> 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)',
-    'Windows Mozilla'	=> 'Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.4b) Gecko/20030516 Mozilla Firebird/0.6',
-    'Mac Safari'	=> 'Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en-us) AppleWebKit/85 (KHTML, like Gecko) Safari/85',
-    'Mac Mozilla'	=> 'Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.4a) Gecko/20030401',
-    'Linux Mozilla'	=> 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.4) Gecko/20030624',
-    'Linux Konqueror'	=> 'Mozilla/5.0 (compatible; Konqueror/3; Linux)',
+    'Windows IE 6'      => 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)',
+    'Windows Mozilla'   => 'Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.4b) Gecko/20030516 Mozilla Firebird/0.6',
+    'Mac Safari'        => 'Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en-us) AppleWebKit/85 (KHTML, like Gecko) Safari/85',
+    'Mac Mozilla'       => 'Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.4a) Gecko/20030401',
+    'Linux Mozilla'     => 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.4) Gecko/20030624',
+    'Linux Konqueror'   => 'Mozilla/5.0 (compatible; Konqueror/3; Linux)',
 );
 
 sub agent_alias {
@@ -293,10 +308,10 @@ sub agent_alias {
     my $alias = shift;
 
     if ( defined $known_agents{$alias} ) {
-	return $self->agent( $known_agents{$alias} );
+        return $self->agent( $known_agents{$alias} );
     } else {
-	$self->warn( qq{Unknown agent alias "$alias"} );
-	return $self->agent();
+        $self->warn( qq{Unknown agent alias "$alias"} );
+        return $self->agent();
     }
 }
 
@@ -315,7 +330,7 @@ sub known_agent_aliases {
 =head2 C<< $a->get($url) >>
 
 Given a URL/URI, fetches it.  Returns an L<HTTP::Response> object.
-I<$url> can be a well-formed URL string, or a URI::* object.
+I<$url> can be a well-formed URL string, or a L<URI> object.
 
 The results are stored internally in the agent object, but you don't
 know that.  Just use the accessors listed below.  Poking at the internals
@@ -336,8 +351,8 @@ sub get {
     my $uri = shift;
 
     $uri = $self->base
-	    ? URI->new_abs( $uri, $self->base )
-	    : URI->new( $uri );
+            ? URI->new_abs( $uri, $self->base )
+            : URI->new( $uri );
 
     return $self->SUPER::get( $uri->as_string, @_ );
 }
@@ -377,7 +392,7 @@ sub back {
 =head2 C<< $a->follow_link(...) >>
 
 Follows a specified link on the page.  You specify the match to be
-found using the same parms that C<find_link()> uses.
+found using the same parms that C<L<find_link()>> uses.
 
 Here some examples:
 
@@ -393,7 +408,7 @@ Here some examples:
 
 or
 
-    $a->follow_link( url_regex => "(?i:download)" );
+    $a->follow_link( url_regex => qr/(?i:download)/ );
 
 =item * 3rd link on the page
 
@@ -415,14 +430,14 @@ sub follow_link {
     my %parms = ( n=>1, @_ );
 
     if ( $parms{n} eq "all" ) {
-	delete $parms{n};
-	$self->warn( qq{follow_link(n=>"all") is not valid} );
+        delete $parms{n};
+        $self->warn( qq{follow_link(n=>"all") is not valid} );
     }
 
     my $response;
     my $link = $self->find_link(%parms);
     if ( $link ) {
-	$response = $self->get( $link->url );
+        $response = $self->get( $link->url );
     }
 
     return $response;
@@ -433,7 +448,7 @@ sub follow_link {
 =head2 C<< $a->form_number($number) >>
 
 Selects the I<number>th form on the page as the target for subsequent
-calls to field() and click().  Also returns the form that was
+calls to C<L<field()>> and C<L<click()>>.  Also returns the form that was
 selected.  Emits a warning and returns undef if there is no such
 form.  Forms are indexed from 1, so the first form is number 1,
 not zero.
@@ -446,7 +461,7 @@ sub form_number {
         $self->{form} = $self->{forms}->[$form-1];
         return $self->{form};
     } else {
-	$self->warn( "There is no form numbered $form" );
+        $self->warn( "There is no form numbered $form" );
         return undef;
     }
 }
@@ -468,11 +483,11 @@ sub form_name {
     my $temp;
     my @matches = grep {defined($temp = $_->attr('name')) and ($temp eq $form) } $self->forms;
     if ( @matches ) {
-	$self->warn( "There are ", scalar @matches, " forms named $form.  The first one was used." )
-	    if @matches > 1;
+        $self->warn( "There are ", scalar @matches, " forms named $form.  The first one was used." )
+            if @matches > 1;
         return $self->{form} = $matches[0];
     } else {
-	$self->warn( qq{ There is no form named "$form"} );
+        $self->warn( qq{ There is no form named "$form"} );
         return undef;
     }
 }
@@ -480,10 +495,10 @@ sub form_name {
 =head2 C<< $a->field($name, $value, $number) >>
 
 Given the name of a field, set its value to the value specified.  This
-applies to the current form (as set by the C<form()> method or defaulting
+applies to the current form (as set by the C<L<form()>> method or defaulting
 to the first form on the page).
 
-The optional C<$number> parameter is used to distinguish between two fields
+The optional I<$number> parameter is used to distinguish between two fields
 with the same name.  The fields are numbered from 1.
 
 =cut
@@ -513,7 +528,7 @@ has the field value and its number as the 2 elements.
 
 The fields are numbered from 1.
 
-This applies to the current form (as set by the C<form()> method or
+This applies to the current form (as set by the C<L<form()>> method or
 defaulting to the first form on the page).
 
 =cut
@@ -552,18 +567,18 @@ sub tick {
     # loop though all the inputs
     my $index = 0;
     while ( my $input = $self->current_form->find_input( $name, "checkbox", $index ) ) {
-	# Can't guarantee that the first element will be undef and the second
-	# element will be the right name
-	foreach my $val ($input->possible_values()) {
-	    next unless defined $val;
-	    if ($val eq $value) {
-		$input->value($set ? $value : undef);
-		return;
-	    }
-	}
+        # Can't guarantee that the first element will be undef and the second
+        # element will be the right name
+        foreach my $val ($input->possible_values()) {
+            next unless defined $val;
+            if ($val eq $value) {
+                $input->value($set ? $value : undef);
+                return;
+            }
+        }
 
-	# move onto the next input
-	$index++;
+        # move onto the next input
+        $index++;
     } # while
 
     # got self far?  Didn't find anything
@@ -632,32 +647,32 @@ are a list of key/value pairs, all of which are optional.
 
 =item * form_number => n
 
-Selects the I<n>th form (calls C<form_number()>).  If this parm is not
+Selects the I<n>th form (calls C<L<form_number()>>).  If this parm is not
 specified, the currently-selected form is used.
 
 =item * form_name => name
 
-Selects the form named I<name> (calls C<form_name()>)
+Selects the form named I<name> (calls C<L<form_name()>>)
 
 =item * fields => fields
 
-Sets the field values from the I<fields> hashref (calls C<set_fields()>)
+Sets the field values from the I<fields> hashref (calls C<L<set_fields()>>)
 
 =item * button => button
 
-Clicks on button I<button> (calls C<click()>)
+Clicks on button I<button> (calls C<L<click()>>)
 
 =item * x => x, y => y
 
-Sets the x or y values for C<click()>
+Sets the x or y values for C<L<click()>>
 
 =back
 
 If no form is selected, the first form found is used.
 
-If I<button> is not passed, then the C<submit()> method is used instead.
+If I<button> is not passed, then the C<L<submit()>> method is used instead.
 
-Returns an HTTP::Response object.
+Returns an L<HTTP::Response> object.
 
 =cut
 
@@ -665,13 +680,13 @@ sub submit_form {
     my( $self, %args ) = @_ ;
 
     for ( keys %args ) {
-	if ( !/^(form_(number|name)|fields|button|x|y)$/ ) {
-	    $self->warn( qq{Unknown submit_form parameter "$_"} );
-	}
+        if ( !/^(form_(number|name)|fields|button|x|y)$/ ) {
+            $self->warn( qq{Unknown submit_form parameter "$_"} );
+        }
     }
 
     if ( my $form_number = $args{'form_number'} ) {
-	$self->form_number( $form_number ) ;
+        $self->form_number( $form_number ) ;
     }
     elsif ( my $form_name = $args{'form_name'} ) {
         $self->form_name( $form_name ) ;
@@ -679,15 +694,15 @@ sub submit_form {
 
     if ( my $fields = $args{'fields'} ) {
         if ( ref $fields eq 'HASH' ) {
-	    $self->set_fields( %{$fields} ) ;
+            $self->set_fields( %{$fields} ) ;
         } # TODO: What if it's not a hash?  We just ignore it silently?
     }
 
     my $response;
     if ( $args{button} ) {
-	$response = $self->click( $args{button}, $args{x} || 0, $args{y} || 0 );
+        $response = $self->click( $args{button}, $args{x} || 0, $args{y} || 0 );
     } else {
-	$response = $self->submit();
+        $response = $self->submit();
     }
 
     return $response;
@@ -747,7 +762,7 @@ objects.
 =head2 C<< $a->current_form() >>
 
 Returns the current form as an L<HTML::Form> object.  I'd call this
-C<form()> except that C<form()> already exists and sets the current_form.
+C<form()> except that C<L<form()>> already exists and sets the current_form.
 
 =head2 C<< $a->links() >>
 
@@ -812,9 +827,9 @@ L<WWW::Mechanize::Link> object which describes the link.  (You'll probably
 be most interested in the C<url()> property.)  If it fails to find a
 link it returns undef.
 
-You can take the URL part and pass it to the C<get()> method.  If that's
-your plan, you might as well use the C<follow_link()> method directly,
-since it does the C<get()> for you automatically.
+You can take the URL part and pass it to the C<L<get()>> method.
+If that's your plan, you might as well use the C<L<follow_link()>>
+method directly, since it does the C<L<get()>> for you automatically.
 
 Note that C<< <FRAME SRC="..."> >> tags are parsed out of the the HTML
 and treated as links so this method works with them.
@@ -824,40 +839,40 @@ key/value pairs:
 
 =over 4
 
-=item * text => string
+=item * C<< text => string >> and C<< text_regex => regex >>
 
-Matches the text of the link against I<string>, which must be an
-exact match.
-
-To select a link with text that is exactly "download", use
+C<text> matches the text of the link against I<string>, which must be an
+exact match.  To select a link with text that is exactly "download", use
 
     $a->find_link( text => "download" );
 
-=item * text_regex => regex
-
-Matches the text of the link against I<regex>.
-
-To select a link with text that has "download" anywhere in it,
-regardless of case, use
+C<text_regex> matches the text of the link against I<regex>.  To select a
+link with text that has "download" anywhere in it, regardless of case, use
 
     $a->find_link( text_regex => qr/download/i );
 
-=item * url => string
+=item * C<< url => string >> and C<< url_regex => regex >>
 
-Matches the URL of the link against I<string>, which must be an
-exact match.  This is similar to the C<text> parm.
+Matches the URL of the link against I<string> or I<regex>, as appropriate.
 
-=item * url_regex => regex
+=item * C<< name => string >> and C<< name_regex => regex >>
 
-Matches the URL of the link against I<regex>.  This is similar to
-the C<text_regex> parm.
+Matches the name of the link against I<string> or I<regex>, as appropriate.
 
-=item * n => I<number>
+=item * C<< tag => string >> and C<< tag_regex => regex >>
+
+Matches the tag that the link came from against I<string> or I<regex>,
+as appropriate.  The C<tag_regex> is probably most useful to check for
+more than one tag, as in:
+
+    $a->find_link( tag_regex => qr/^(a|img)$/;
+
+=item * C<< n => number >>
 
 Matches against the I<n>th link.
 
-The C<n> parms can be combined with the C<text*> or C<url*> parms
-as a numeric modifier.  For example, 
+The C<n> parms can be combined with the other parms above as a numeric
+modifier.  For example,
 C<< text => "download", n => 3 >> finds the 3rd link which has the
 exact text "download".
 
@@ -893,18 +908,6 @@ The links come from the following:
 
 =back
 
-The array elements are:
-
-=over 4
-
-=item [0]: contents of the link
-
-=item [1]: text enclosed by the tag
-
-=item [2]: the contents of the C<NAME> attribute
-
-=back
-
 =cut
 
 sub find_link {
@@ -914,52 +917,56 @@ sub find_link {
     my $wantall = ( $parms{n} eq "all" );
 
     for my $key ( keys %parms ) {
-	my $val = $parms{$key};
-	if ( $key !~ /^(n|(text|url)(_regex)?)$/ ) {
-	    $self->warn( qq{Unknown link-finding parameter "$key"} );
-	    delete $parms{$key};
-	    next;
-	}
+        my $val = $parms{$key};
+        if ( $key !~ /^(n|(text|url|name|tag)(_regex)?)$/ ) {
+            $self->warn( qq{Unknown link-finding parameter "$key"} );
+            delete $parms{$key};
+            next;
+        }
 
-	if ( ($key =~ /_regex$/) && (ref($val) ne "Regexp" ) ) {
-	    $self->warn( qq{$val passed as $key is not a regex} );
-	    delete $parms{$key};
-	    next;
-	}
+        if ( ($key =~ /_regex$/) && (ref($val) ne "Regexp" ) ) {
+            $self->warn( qq{$val passed as $key is not a regex} );
+            delete $parms{$key};
+            next;
+        }
     } # for keys %parms
 
     my @links = $self->links or return;
 
     my @conditions;
-    push @conditions, q/ $_[0]->[0] eq $parms{url} /				    if defined $parms{url};
-    push @conditions, q/ $_[0]->[0] =~ $parms{url_regex} /			    if defined $parms{url_regex};
-    push @conditions, q/ defined($_[0]->[1]) and $_[0]->[1] eq $parms{text} /	    if defined $parms{text};
+    push @conditions, q/ $_[0]->[0] eq $parms{url} /                                if defined $parms{url};
+    push @conditions, q/ $_[0]->[0] =~ $parms{url_regex} /                          if defined $parms{url_regex};
+    push @conditions, q/ defined($_[0]->[1]) and $_[0]->[1] eq $parms{text} /       if defined $parms{text};
     push @conditions, q/ defined($_[0]->[1]) and $_[0]->[1] =~ $parms{text_regex} / if defined $parms{text_regex};
+    push @conditions, q/ defined($_[0]->[2]) and $_[0]->[2] eq $parms{name} /       if defined $parms{name};
+    push @conditions, q/ defined($_[0]->[2]) and $_[0]->[2] =~ $parms{name_regex} / if defined $parms{name_regex};
+    push @conditions, q/ $_[0]->[3] and $_[0]->[3] eq $parms{tag} /                 if defined $parms{tag};
+    push @conditions, q/ $_[0]->[3] and $_[0]->[3] =~ $parms{tag_regex} /           if defined $parms{tag_regex};
 
     my $matchfunc;
     if ( @conditions ) {
-	local $" = " && ";
-	$matchfunc = eval "sub { @conditions }";
+        local $" = " && ";
+        $matchfunc = eval "sub { @conditions }";
     } else {
-	$matchfunc = sub{1};
+        $matchfunc = sub{1};
     }
 
     my $nmatches = 0;
     my @matches;
     for my $link ( @links ) {
-	if ( $matchfunc->($link) ) {
-	    if ( $wantall ) {
-		push( @matches, $link );
-	    } else {
-		++$nmatches;
-		return $link if $nmatches >= $parms{n};
-	    }
-	}
+        if ( $matchfunc->($link) ) {
+            if ( $wantall ) {
+                push( @matches, $link );
+            } else {
+                ++$nmatches;
+                return $link if $nmatches >= $parms{n};
+            }
+        }
     } # for @links
 
     if ( $wantall ) {
-	return @matches if wantarray;
-	return \@matches;
+        return @matches if wantarray;
+        return \@matches;
     }
 
     return;
@@ -967,10 +974,9 @@ sub find_link {
 
 =head2 C<< $a->find_all_links( ... ) >>
 
-Returns all the links on the current page that match the criteria.
-The method for specifying link criteria is the same as in
-C<find_link()>.  Each of the links returned is in the same format
-as in C<find_link()>.
+Returns all the links on the current page that match the criteria.  The
+method for specifying link criteria is the same as in C<L<find_link()>>.
+Each of the links returned is a L<WWW::Mechanize::Link> object.
 
 In list context, C<find_all_links()> returns a list of the links.
 Otherwise, it returns a reference to the list of links.
@@ -1047,10 +1053,10 @@ sub redirect_ok {
 
     my $ok = $self->SUPER::redirect_ok( $prospective_request );
     if ( $ok ) {
-	$self->{redirected_uri} = $prospective_request->uri;
+        $self->{redirected_uri} = $prospective_request->uri;
 
-	# Mimic erroneous browser behaviour by changing the method.
-	$prospective_request->method("GET") if $prospective_request->method eq "POST";
+        # Mimic erroneous browser behaviour by changing the method.
+        $prospective_request->method("GET") if $prospective_request->method eq "POST";
     }
 
     return $ok;
@@ -1074,7 +1080,7 @@ sub request {
     my $request = shift;
 
     if ( $request->method eq "GET" || $request->method eq "POST" ) {
-	$self->_push_page_stack();
+        $self->_push_page_stack();
     }
 
     $request->header( Referer => $self->{last_uri} ) if $self->{last_uri};
@@ -1092,12 +1098,12 @@ sub request {
     $self->{ct}      = $res->content_type || "";
     $self->{content} = $res->content;
     if ( $self->{res}->is_success ) {
-	$self->{uri} = $self->{redirected_uri};
-	$self->{last_uri} = $self->{uri};
+        $self->{uri} = $self->{redirected_uri};
+        $self->{last_uri} = $self->{uri};
     } else {
-	if ( $self->{autocheck} ) {
-	    $self->die( "Error ", $request->method, "ing ", $request->uri, ": ", $res->message );
-	}
+        if ( $self->{autocheck} ) {
+            $self->die( "Error ", $request->method, "ing ", $request->uri, ": ", $res->message );
+        }
     }
 
     $self->_reset_page();
@@ -1113,7 +1119,7 @@ sub request {
 =head2 C<_make_request()>
 
 Convenience method to make it easier for subclasses like
-WWW::Mechanize::Cached to intercept the request.
+L<WWW::Mechanize::Cached> to intercept the request.
 
 =cut
 
@@ -1129,7 +1135,7 @@ Please use them instead.
 
 =head2 C<< $a->follow($string|$num) >>
 
-B<DEPRECATED> in favor of C<follow_link()>, which provides more
+B<DEPRECATED> in favor of C<L<follow_link()>>, which provides more
 flexibility.
 
 Follow a link.  If you provide a string, the first link whose text
@@ -1149,7 +1155,7 @@ sub follow {
         if ($link <= $#links) {
             $thislink = $links[$link];
         } else {
-	    $self->warn( "Link number $link is greater than maximum link $#links on this page ($self->{uri})" );
+            $self->warn( "Link number $link is greater than maximum link $#links on this page ($self->{uri})" );
             return;
         }
     } else {                        # user provided a regexp
@@ -1160,7 +1166,7 @@ sub follow {
             }
         }
         unless ($thislink) {
-	    $self->warn( "Can't find any link matching $link on this page ($self->{uri})" );
+            $self->warn( "Can't find any link matching $link on this page ($self->{uri})" );
             return;
         }
     }
@@ -1174,7 +1180,7 @@ sub follow {
 
 =head2 C<< $a->form($number|$name) >>
 
-B<DEPRECATED> in favor of C<form_name()> or C<form_number()>.
+B<DEPRECATED> in favor of C<L<form_name()>> or C<L<form_number()>>.
 
 Selects a form by number or name, depending on if it gets passed an
 all-numeric string or not.  This means that if you have a form name
@@ -1240,14 +1246,14 @@ sub _extract_links {
         next unless defined $url;   # probably just a name link or <AREA NOHREF...>
 
         my $text;
-	my $name;
-	if ( $tag eq "a" ) {
-	    $text = $p->get_trimmed_text("/$tag");
-	    $text = "" unless defined $text;
-	}
-	if ( $tag ne "area" ) {
-	    $name = $token->[1]{name};
-	}
+        my $name;
+        if ( $tag eq "a" ) {
+            $text = $p->get_trimmed_text("/$tag");
+            $text = "" unless defined $text;
+        }
+        if ( $tag ne "area" ) {
+            $name = $token->[1]{name};
+        }
 
         push( @{$self->{links}}, WWW::Mechanize::Link->new( $url, $text, $name, $tag ) );
     }
@@ -1255,8 +1261,8 @@ sub _extract_links {
     # Old extract_links() returned a value.  Carp if someone expects
     # this version to return something.
     if ( defined wantarray ) {
-	my $func = (caller(0))[3];
-	$self->warn( "$func does not return a useful value" );
+        my $func = (caller(0))[3];
+        $self->warn( "$func does not return a useful value" );
     }
 
     return;
@@ -1280,12 +1286,12 @@ sub _push_page_stack {
 
     # Don't push anything if it's a virgin object
     if ( $self->{res} ) {
-	my $save_stack = $self->{page_stack};
-	$self->{page_stack} = [];
+        my $save_stack = $self->{page_stack};
+        $self->{page_stack} = [];
 
-	push( @$save_stack, $self->clone );
+        push( @$save_stack, $self->clone );
 
-	$self->{page_stack} = $save_stack;
+        $self->{page_stack} = $save_stack;
     }
 
     return 1;
@@ -1334,9 +1340,9 @@ sub die {
 sub _warn {
     eval "require Carp";
     if ( $@ ) {
-	CORE::warn @_;
+        CORE::warn @_;
     } else {
-	&Carp::carp; # pass thru
+        &Carp::carp; # pass thru
     }
     return;
 }
@@ -1345,9 +1351,9 @@ sub _warn {
 sub _die {
     eval "require Carp";
     if ( $@ ) {
-	CORE::die @_;
+        CORE::die @_;
     } else {
-	&Carp::croak; # pass thru
+        &Carp::croak; # pass thru
     }
     return;
 }
